VOL-4238: Bugfix for invalid code-generated class IDs from 11/2017 version of G.988.  Specifically EthernetFrameExtendedPm64BitClassID

Change-Id: I326273386e2f1b39a60d5f8e800dba74a652c84f
diff --git a/generated/efmbondinggroupperformancemonitoringhistorydata.go b/generated/efmbondinggroupperformancemonitoringhistorydata.go
index a73c150..6157d8f 100644
--- a/generated/efmbondinggroupperformancemonitoringhistorydata.go
+++ b/generated/efmbondinggroupperformancemonitoringhistorydata.go
@@ -27,11 +27,11 @@
 
 // EfmBondingGroupPerformanceMonitoringHistoryDataClassID is the 16-bit ID for the OMCI
 // Managed entity EFM bonding group performance monitoring history data
-const EfmBondingGroupPerformanceMonitoringHistoryDataClassID ClassID = ClassID(421)
+const EfmBondingGroupPerformanceMonitoringHistoryDataClassID ClassID = ClassID(420)
 
 var efmbondinggroupperformancemonitoringhistorydataBME *ManagedEntityDefinition
 
-// EfmBondingGroupPerformanceMonitoringHistoryData (class ID #421)
+// EfmBondingGroupPerformanceMonitoringHistoryData (class ID #420)
 //	This ME collects PM data as seen at the xTU-C. Instances of this ME are created and deleted by
 //	the OLT.
 //
@@ -94,7 +94,7 @@
 func init() {
 	efmbondinggroupperformancemonitoringhistorydataBME = &ManagedEntityDefinition{
 		Name:    "EfmBondingGroupPerformanceMonitoringHistoryData",
-		ClassID: 421,
+		ClassID: 420,
 		MessageTypes: mapset.NewSetWith(
 			Create,
 			Delete,
@@ -129,7 +129,7 @@
 	}
 }
 
 // NewEfmBondingGroupPerformanceMonitoringHistoryData (class ID 421) creates the basic
 // Managed Entity definition that is used to validate an ME of this type that
 // is received from or transmitted to the OMCC.
 func NewEfmBondingGroupPerformanceMonitoringHistoryData(params ...ParamData) (*ManagedEntity, OmciErrors) {
@@ -129,7 +129,7 @@
 }
 
-// NewEfmBondingGroupPerformanceMonitoringHistoryData (class ID 421) creates the basic
+// NewEfmBondingGroupPerformanceMonitoringHistoryData (class ID 420) creates the basic
 // Managed Entity definition that is used to validate an ME of this type that
 // is received from or transmitted to the OMCC.